#!/usr/bin/env python3
"""
Version information for the Secure File Encryption Tool.
"""

# This file is automatically generated by setup.py
__version__ = "0.5.3"
__git_commit__ = "bdd8e4a4da398acefe34224f83191edbe6d6160c"
__author__ = "Tobi <jahlives@gmx.ch>"
__license__ = "MIT"
__copyright__ = "by " + __author__

# Version history
VERSION_HISTORY = {
    "0.1.0": "Initial release",
    "0.2.0": "Added support for AES-GCM and ChaCha20-Poly1305",
    "0.3.0": "Added support for Argon2 key derivation",
    "0.4.0": "Added secure memory handling and improved password strength",
    "0.4.4": "Added support for Scrypt and more hash algorithms",
    "0.5.0": "Added BLAKE2b and SHAKE-256 hash algorithms, XChaCha20-Poly1305 encryption",
    "0.5.1": "More reliable approach to get commit sha into version.py",
    "0.5.2": "Added postquantum resistant encryption via a hypbrid approach",
    "0.5.3": "Security release with additional buffer overflow protection and better secure memory handling"
}

# Check for updates
def get_latest_version():
    """Return the latest version number."""
    return __version__

def get_version_info():
    """Return version information as a dictionary."""
    return {
        "version": __version__,
        "git_commit": __git_commit__,
        "author": __author__,
        "license": __license__,
        "copyright": __copyright__,
        "history": VERSION_HISTORY
    }

def print_version_info():
    """Print version information to the console."""
    print(f"Secure File Encryption Tool v{__version__}")
    print(f"Git commit: {__git_commit__}")
    print(f"Author: {__author__}")
    print(f"License: {__license__}")
    print(f"{__copyright__}")
    print("\nVersion History:")
    for version, description in VERSION_HISTORY.items():
        print(f"  {version}: {description}")
        
if __name__ == "__main__":
    print_version_info()
